Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(320)

Unified Diff: runtime/observatory/tests/service/step_over_await_test.dart

Issue 2785243003: Implement support for single stepping out of an async function. (Closed)
Patch Set: fschneider review Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/observatory/tests/service/smart_next_test.dart ('k') | runtime/vm/debugger.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/observatory/tests/service/step_over_await_test.dart
diff --git a/runtime/observatory/tests/service/step_over_await_test.dart b/runtime/observatory/tests/service/step_over_await_test.dart
index f1e8d7ceea177103e7c9e1735d031753fba5e12e..c00cc91b8498740cb7efd48e8f3d67c52bd4575d 100644
--- a/runtime/observatory/tests/service/step_over_await_test.dart
+++ b/runtime/observatory/tests/service/step_over_await_test.dart
@@ -16,7 +16,7 @@ import 'package:unittest/unittest.dart';
const int LINE_A = 22;
const int LINE_B = 24;
// This tests the asyncStepOver command.
asyncFunction() async {
debugger();
print('a'); // LINE_A
@@ -38,7 +38,8 @@ var tests = [
(Isolate isolate) async {
expect(M.isAtAsyncSuspension(isolate.pauseEvent), isTrue);
},
- asyncStepOver,
+ asyncNext,
+ hasStoppedAtBreakpoint,
stoppedAtLine(LINE_B),
resumeIsolate,
];
@@ -16,7 +16,7 @@ import 'package:unittest/unittest.dart';
const int LINE_A = 22;
const int LINE_B = 24;
-// This tests the asyncStepOver command.
+// This tests the asyncNext command.
asyncFunction() async {
debugger();
« no previous file with comments | « runtime/observatory/tests/service/smart_next_test.dart ('k') | runtime/vm/debugger.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698